# User Guide

This section provides all the information required to build your custom eFPGA and to use the fabricated or emulated design. To learn how to build your custom fabric, check out the [fabric building documentation](#fabric-building). To learn about how to program the eFPGA (which we refer to as "configuration"), check out the [fabric using documentation](#fabric-using). Whether being a user or designer, everything can be driven by our interactive CLI. For more detail of the capability of the CLI check out the [CLI documentation](#CLI-usage).

```{toctree}
:maxdepth: 2

building_doc/index
using_doc/index
cli_doc/index
simulation/index
```
